@@ -10,7 +10,7 @@ use Time::HiRes qw(time);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-12-09'; # DATE
 our $DIST = 'App-CekBpom'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(cek_bpom_products);
@@ -367,7 +367,7 @@ sub cek_bpom_products {
         };
     }
 
-    $resmeta{title} = "Check BPOM products: query=$args{queries}, search_types=[".join(",",@$search_types)."]";
+    $resmeta{title} = "Check BPOM products: query=[".join(",", @{$args{queries}})."], search_types=[".join(",",@$search_types)."]";
 
     $envres;
 }
@@ -387,7 +387,7 @@ App::CekBpom - Check BPOM products/manufacturers ("sarana") via the command-line
 
 =head1 VERSION
 
-This document describes version 0.015 of App::CekBpom (from Perl distribution App-CekBpom), released on 2021-12-09.
+This document describes version 0.016 of App::CekBpom (from Perl distribution App-CekBpom), released on 2021-12-09.
 
 =head1 DESCRIPTION
 
